@@ -19,14 +19,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dbprovider.c,v 1.39 2013/07/10 22:35:13 mdpetch Exp $
+ * $Id: dbprovider.c,v 1.42 2013/07/26 21:20:46 plm Exp $
  */
 
 #include "config.h"
 #include "gnubgmodule.h"
 
 #include "backgammon.h"
-#include <stdlib.h>
 #include <glib/gstdio.h>
 #include <string.h>
 #include "dbprovider.h"
@@ -158,7 +157,7 @@ RunQueryValue(const DBProvider * pdb, const char *query)
     RowSet *rs;
     rs = pdb->Select(query);
     if (rs && rs->rows > 1) {
-        int id = strtol(rs->data[1][0], NULL, 0);
+        int id = (int)strtol(rs->data[1][0], NULL, 0);
         FreeRowset(rs);
         return id;
     } else
@@ -553,7 +552,7 @@ PyPostgreDeleteDatabase(const char *dbfilename, const char *user, const char *pa
     if (PyPostgreConnect("postgres", user, password, hostname) < 0)
         return FALSE;
 
-    ret = PyUpdateCommand("END");
+    PyUpdateCommand("END");
     buf = g_strdup_printf("DROP DATABASE %s", dbfilename);
     ret = PyUpdateCommand(buf);
     g_free(buf);
