@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: export.c,v 1.77 2013/06/16 02:16:11 mdpetch Exp $
+ * $Id: export.c,v 1.78 2013/07/26 21:21:34 plm Exp $
  */
 
 #include "config.h"
@@ -770,7 +770,7 @@ ExportSnowieTxt(char *sz, const matchstate * pms)
 
     /* dice */
 
-    sz += sprintf(sz, "%d;%d;", (pms->anDice[0] > 0) ? pms->anDice[0] : 0, (pms->anDice[1] > 0) ? pms->anDice[1] : 0);
+    sprintf(sz, "%d;%d;", (pms->anDice[0] > 0) ? pms->anDice[0] : 0, (pms->anDice[1] > 0) ? pms->anDice[1] : 0);
 
 }
 
