@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gnubgmodule.c,v 1.159 2013/07/10 20:51:45 mdpetch Exp $
+ * $Id: gnubgmodule.c,v 1.162 2013/07/28 16:25:17 mdpetch Exp $
  */
 
 #include "config.h"
@@ -636,13 +636,13 @@ PythonHint_Callback (procrecorddata *pr)
     }
     if (hintdict){
         PyList_Append (list, hintdict);
-        Py_DecRef(hintdict);
+        Py_DECREF(hintdict);
     }
         
     return TRUE;
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PythonHint(PyObject * UNUSED(self), PyObject * args)
 {
     PyObject *retval = NULL, *gnubgid = NULL, *tmpobj;
@@ -909,7 +909,7 @@ PythonMoveTuple2String(PyObject * UNUSED(self), PyObject * args)
     return PyString_FromString(szMove);
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PythonEvaluate(PyObject * UNUSED(self), PyObject * args)
 {
 
@@ -952,7 +952,7 @@ PythonEvaluate(PyObject * UNUSED(self), PyObject * args)
     }
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PythonEvaluateCubeful(PyObject * UNUSED(self), PyObject * args)
 {
 
@@ -1002,7 +1002,7 @@ PythonEvaluateCubeful(PyObject * UNUSED(self), PyObject * args)
     }
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PythonFindBestMove(PyObject * UNUSED(self), PyObject * args)
 {
 
@@ -1195,7 +1195,7 @@ PythonMET(PyObject * UNUSED(self), PyObject * args)
 
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PythonEq2mwcStdErr(PyObject * UNUSED(self), PyObject * args)
 {
 
@@ -1215,7 +1215,7 @@ PythonEq2mwcStdErr(PyObject * UNUSED(self), PyObject * args)
 
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PythonEq2mwc(PyObject * UNUSED(self), PyObject * args)
 {
 
@@ -1241,7 +1241,7 @@ PythonMatchChecksum(PyObject * UNUSED(self), PyObject * UNUSED(args))
     return PyString_FromString(GetMatchCheckSum());
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PythonMwc2eq(PyObject * UNUSED(self), PyObject * args)
 {
 
@@ -1260,7 +1260,7 @@ PythonMwc2eq(PyObject * UNUSED(self), PyObject * args)
     return PyFloat_FromDouble(mwc2eq(r, &ci));
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PythonMwc2eqStdErr(PyObject * UNUSED(self), PyObject * args)
 {
 
@@ -1867,7 +1867,7 @@ addLuck(PyObject * dict, float const rLuck, lucktype const lt)
     }
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PyMoveAnalysis(const movelist * pml, PyMatchState * ms)
 {
     unsigned int i;
@@ -1966,7 +1966,7 @@ PyMoveAnalysis(const movelist * pml, PyMatchState * ms)
     }
 }
 
-STACKALIGN static PyObject *
+SIMD_STACKALIGN static PyObject *
 PyDoubleAnalysis(const evalsetup * pes,
                  float aarOutput[][NUM_ROLLOUT_OUTPUTS],
                  float aarStdDev[][NUM_ROLLOUT_OUTPUTS], PyMatchState * ms, int const verbose)
@@ -2752,11 +2752,10 @@ PythonNavigate(PyObject * UNUSED(self), PyObject * args, PyObject * keywds)
         if (nextGame != INT_MIN && nextGame != 0) {
             listOLD *pl = lMatch.plNext;
 
-            for (; pl->p != plGame && pl != &lMatch; pl = pl->plNext);
+            for (; pl->p != plGame && pl != &lMatch; pl = pl->plNext)
+                ;
+            g_assert(pl->p == plGame);
 
-            {
-                g_assert(pl->p == plGame);
-            }
             {
                 int n = nextGame;
                 if (n > 0) {
@@ -3097,10 +3096,12 @@ python_run_file(gpointer file)
     py_dict = PyModule_GetDict(PythonGnubgModule());
     py_ret = PyRun_String(pch, Py_eval_input, PythonGnubgModule(), py_dict);
 
-    if (py_ret)
+    if (py_ret) {
         Py_DECREF(py_ret);
-    if (py_ret)
+    }
+    if (py_ret) {
         Py_DECREF(py_dict);
+    }
     g_free(pch);
     g_free(file);
     return FALSE;
@@ -3152,8 +3153,9 @@ PythonShutdown(void)
         python_dir = NULL;
     }
 #endif
-    if (py_gnubg_module)
+    if (py_gnubg_module) {
         Py_DECREF(py_gnubg_module);
+    }
 
     py_gnubg_module = NULL;
 }
@@ -3180,10 +3182,12 @@ PythonRun(const char *sz)
             if (py_ret && PyInt_Check(py_ret) && PyInt_AsLong(py_ret))
                 success = TRUE;
 
-        if (py_ret)
+        if (py_ret) {
             Py_DECREF(py_ret);
-        if (py_dict)
+        }
+        if (py_dict) {
             Py_DECREF(py_dict);
+        }
 
         if (success)
             return;
