@@ -16,20 +16,26 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkgame.h,v 1.130 2008/03/16 16:56:45 Superfly_Jon Exp $
+ * $Id: gtkgame.h,v 1.153 2013/06/16 02:16:14 mdpetch Exp $
  */
 
-#ifndef _GTKGAME_H_
-#define _GTKGAME_H_
+#ifndef GTKGAME_H
+#define GTKGAME_H
+
 #include <gtk/gtk.h>
 #include "backgammon.h"
 #include "gtkpanels.h"
 #include "gtkchequer.h"
 
+#define TOOLBAR_ACTION_OFFSET 10000
+
+#if (USE_GTKUIMANAGER)
+extern GtkUIManager *puim;
+#endif
+
 extern GdkColor wlCol;
 extern GtkAccelGroup *pagMain;
-extern GtkItemFactory *pif;
-extern GtkTooltips *ptt;
+
 extern GtkWidget *pwAnalysis;
 extern GtkWidget *pwBoard;
 extern GtkWidget *pwCommentary;
@@ -40,7 +46,8 @@ extern GtkWidget *pwMoveAnalysis;
 extern GtkWidget *pwOldGrab;
 extern GtkWidget *pwPanelVbox;
 extern GtkWidget *pwToolbar;
-extern guint nNextTurn;		/* GTK idle function */
+extern GtkWidget *pwGnubgID;
+extern guint nNextTurn;         /* GTK idle function */
 extern int fEndDelay;
 extern int fNeedPrompt;
 extern int frozen;
@@ -55,14 +62,11 @@ extern moverecord *pmrCurAnn;
 
 extern char *ReturnHits(TanBoard anBoard);
 extern gboolean ShowGameWindow(void);
-extern gint MoveListClearSelection(GtkWidget * pw, GdkEventSelection * pes,
-				   hintdata * phd);
+extern gint MoveListClearSelection(GtkWidget * pw, GdkEventSelection * pes, hintdata * phd);
 extern gint NextTurnNotify(gpointer p);
 extern GList *MoveListGetSelectionList(const hintdata * phd);
 extern GtkWidget *GetPanelWidget(gnubgwindow window);
 extern GtkWidget *GL_Create(void);
-extern GtkWidget *StatsPixmapButton(GdkColormap * pcmap, char **xpm,
-				    void (*fn) (GtkWidget*, char*));
 extern int ArePanelsDocked(void);
 extern int ArePanelsShowing(void);
 extern int DockedPanelsShowing(void);
@@ -80,8 +84,7 @@ extern void DisplayWindows(void);
 extern void DockPanels(void);
 extern void FullScreenMode(int state);
 extern void GetFullscreenWindowSettings(int *panels, int *ids, int *maxed);
-extern void GetStyleFromRCFile(GtkStyle ** ppStyle, char *name,
-			       GtkStyle * psBase);
+extern void GetStyleFromRCFile(GtkStyle ** ppStyle, const char *name, GtkStyle * psBase);
 extern void GL_Freeze(void);
 extern void GL_SetNames(void);
 extern void GL_Thaw(void);
@@ -95,16 +98,14 @@ extern void GTKCalibrationUpdate(void *context, float rEvalsPerSec);
 extern void GtkChangeLanguage(void);
 extern void GTKClearMoveRecord(void);
 extern void GTKCommandShowCredits(GtkWidget * pw, GtkWidget * parent);
-extern void GTKCubeHint(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
-			float aarStdDev[2][NUM_ROLLOUT_OUTPUTS],
-			const evalsetup * pes);
+extern void GTKCubeHint(moverecord * pmr, const matchstate * pms, int did_double, int did_take, int hist);
 extern void GTKDelay(void);
 extern void GTKDisallowStdin(void);
 extern void GTKDumpStatcontext(int game);
 extern void GTKEval(char *szOutput);
 extern void GTKFreeze(void);
 extern void GTKHelp(char *sz);
-extern void GTKHint(movelist * pmlOrig, const unsigned int iMove);
+extern void GTKHint(moverecord * pmr, int hist);
 extern void GTKMatchInfo(void);
 extern void GTKNew(void);
 extern void GTKOutput(const char *sz);
@@ -121,8 +122,7 @@ extern void GTKProgress(void);
 extern void GTKRecordShow(FILE * pfIn, char *sz, char *szPlayer);
 extern void GTKRegenerateGames(void);
 extern void GTKResign(gpointer p, guint n, GtkWidget * pw);
-extern void GTKResignHint(float arOutput[], float rEqBefore,
-			  float rEqAfter, cubeinfo * pci, int fMWC);
+extern void GTKResignHint(float arOutput[], float rEqBefore, float rEqAfter, cubeinfo * pci, int fMWC);
 extern void GTKResumeInput(void);
 extern void GTKSaveSettings(void);
 extern void GTKSetCube(gpointer p, guint n, GtkWidget * pw);
@@ -136,13 +136,10 @@ extern void GTKShowScoreSheet(void);
 extern void GTKShowVersion(void);
 extern void GTKSuspendInput(void);
 extern void GTKTextToClipboard(const char *sz);
-extern void GTKTextWindow(const char *szOutput, const char *title,
-			  const int type);
+extern void GTKTextWindow(const char *szOutput, const char *title, const int type, GtkWidget * parent);
 extern void GTKThaw(void);
-extern void GTKUpdateAnnotations(void);
 extern void HideAllPanels(gpointer p, guint n, GtkWidget * pw);
-extern void HintDoubleClick(GtkTreeView * treeview, GtkTreePath * path,
-			    GtkTreeViewColumn * col, hintdata * phd);
+extern void HintDoubleClick(GtkTreeView * treeview, GtkTreePath * path, GtkTreeViewColumn * col, hintdata * phd);
 extern void HintSelect(GtkTreeSelection * selection, hintdata * phd);
 extern void InitGTK(int *argc, char ***argv);
 extern void MoveListCreate(hintdata * phd);
@@ -153,10 +150,9 @@ extern void OK(GtkWidget * pw, int *pf);
 extern void PanelHide(gnubgwindow panel);
 extern void PanelShow(gnubgwindow panel);
 extern void RefreshGeometries(void);
-extern void RunGTK(GtkWidget * pwSplash, char *commands,
-		   char *python_script, char *match);
+extern void RunGTK(GtkWidget * pwSplash, char *commands, char *python_script, char *match);
 extern void SetAnnotation(moverecord * pmr);
-extern void SetEvaluation(gpointer p, guint n, GtkWidget * pw);
+extern void SetAnalysis(gpointer p, guint n, GtkWidget * pw);
 extern void SetMET(GtkWidget * pw, gpointer p);
 extern void SetPanelWidget(gnubgwindow window, GtkWidget * pWin);
 extern void SetRollouts(gpointer p, guint n, GtkWidget * pw);
@@ -164,14 +160,22 @@ extern void SetToolbarStyle(int value);
 extern void setWindowGeometry(gnubgwindow window);
 extern void ShowAllPanels(gpointer p, guint n, GtkWidget * pw);
 extern void ShowHidePanel(gnubgwindow panel);
-extern void ShowList(char *asz[], char *szTitle, GtkWidget * pwParent);
+extern void ShowList(char *asz[], const char *szTitle, GtkWidget * parent);
 extern void ShowMove(hintdata * phd, const int f);
-extern void SwapBoardToPanel(int ToPanel);
+extern void SwapBoardToPanel(int ToPanel, int updateEvents);
+extern void DoHideAllPanels(int updateEvents);
+#if (USE_GTKUIMANAGER)
+extern void ToggleEdit(GtkToggleAction * action, gpointer user_data);
+extern void ToggleClockwise(GtkToggleAction * action, gpointer user_data);
+extern void ToggleDockPanels(GtkToggleAction * action, gpointer user_data);
+#else
 extern void ToggleDockPanels(gpointer p, guint n, GtkWidget * pw);
+#endif
 extern void GTKUndo(void);
-extern void UserCommand(char *sz);
+extern void UserCommand(const char *sz);
 extern void ShowToolbar(void);
 extern void HideToolbar(void);
+extern void MoveListDestroy(void);
 
 #if HAVE_LIBREADLINE
 extern int fReadingCommand;
@@ -183,4 +187,7 @@ extern void SetSwitchModeMenuText(void);
 extern gboolean gtk_gl_init_success;
 #endif
 
+extern GtkWidget *get_statusbar_label(GtkStatusbar * statusbar);
+extern void toolbar_set_orientation(GtkToolbar * toolbar, GtkOrientation orientation);
+
 #endif
