@@ -16,19 +16,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkprefs.h,v 1.12 2007/07/02 12:43:39 ace Exp $
+ * $Id: gtkprefs.h,v 1.16 2013/06/16 02:16:16 mdpetch Exp $
  */
 
-#ifndef _GTKPREFS_H_
-#define _GTKPREFS_H_
+#ifndef GTKPREFS_H
+#define GTKPREFS_H
 
 #include "gtkboard.h"
 
-extern void BoardPreferences( GtkWidget *pwBoard );
-extern void BoardPreferencesStart( GtkWidget *pwBoard );
-extern void BoardPreferencesDone( GtkWidget *pwBoard );
-extern void Default3dSettings(BoardData* bd);
-extern void UpdatePreview(GtkWidget *notused);
+extern void BoardPreferences(GtkWidget * pwBoard);
+extern void SetBoardPreferences(GtkWidget * pwBoard, char *sz);
+extern void Default3dSettings(BoardData * bd);
+extern void UpdatePreview(void);
+extern void gtk_color_button_get_array(GtkColorButton * button, double array[4]);
+extern void gtk_color_button_set_from_array(GtkColorButton * button, double array[4]);
 
 extern GtkWidget *pwPrevBoard;
 
