@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * 
- * $Id: multithread.c,v 1.85 2013/07/10 20:51:46 mdpetch Exp $
+ * $Id: multithread.c,v 1.87 2013/07/21 00:58:40 mdpetch Exp $
  */
 
 #include "config.h"
@@ -102,13 +102,14 @@ MT_AbortTasks(void)
 }
 
 #ifdef GLIB_THREADS
-static gpointer
+static SIMD_STACKALIGN gpointer
 MT_WorkerThreadFunction(void *tld)
 #else
-static void
+static SIMD_STACKALIGN void
 MT_WorkerThreadFunction(void *tld)
 #endif
 {
+#if 0
     /* why do we need this align ? - because of a gcc bug */
 #if __GNUC__ && defined(WIN32)
     /* Align stack pointer on 16/32 byte boundary so SSE/AVX variables work correctly */
@@ -120,6 +121,8 @@ MT_WorkerThreadFunction(void *tld)
     asm __volatile__("andl $-16, %%esp":::"%esp");
     align_offset = ((int) (&align_offset)) % 16;
 #endif
+#endif
+
 #endif
     {
         ThreadLocalData *pTLD = (ThreadLocalData *) tld;
@@ -138,9 +141,11 @@ MT_WorkerThreadFunction(void *tld)
         } while (!td.closingThreads);
 
 #ifdef GLIB_THREADS
+#if 0
 #if __GNUC__ && defined(WIN32)
         /* De-align stack pointer to avoid crash on exit */
         asm __volatile__("addl %0, %%esp"::"r"(align_offset):"%esp");
+#endif
 #endif
         return NULL;
 #endif
@@ -420,7 +425,7 @@ int
 MT_WaitForTasks(gboolean(*pCallback) (gpointer), int callbackTime, int autosave)
 {
     GList *member;
-    guint as_source = 0;
+    guint as_source, cb_source = 0;
     td.doneTasks = 0;
 
 #if USE_GTK
@@ -430,7 +435,7 @@ MT_WaitForTasks(gboolean(*pCallback) (gpointer), int callbackTime, int autosave)
     multi_debug("Waiting for all tasks");
 
     pCallback(NULL);
-    g_timeout_add(1000, pCallback, NULL);
+    cb_source = g_timeout_add(1000, pCallback, NULL);
     if (autosave)
         as_source = g_timeout_add(nAutoSaveTime * 60000, save_autosave, NULL);
     for (member = g_list_first(td.tasks); member; member = member->next, td.doneTasks++) {
@@ -445,6 +450,8 @@ MT_WaitForTasks(gboolean(*pCallback) (gpointer), int callbackTime, int autosave)
         g_source_remove(as_source);
         save_autosave(NULL);
     }
+
+    g_source_remove(cb_source);
     td.tasks = NULL;
 
 #if USE_GTK
