@@ -16,27 +16,26 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: renderprefs.h,v 1.6 2007/07/02 12:43:40 ace Exp $
+ * $Id: renderprefs.h,v 1.11 2013/06/16 02:16:20 mdpetch Exp $
  */
 
-#ifndef _RENDERPREFS_H_
-#define _RENDERPREFS_H_
+#ifndef RENDERPREFS_H
+#define RENDERPREFS_H
 
-#ifndef _RENDER_H_
+#ifndef RENDER_H
 #include "render.h"
 #endif
 
-extern char *aszWoodName[];
-extern renderdata* GetMainAppearance(void);
-extern void CopyAppearance(renderdata* prd);
+extern const char *aszWoodName[];
+extern renderdata *GetMainAppearance(void);
+extern void CopyAppearance(renderdata * prd);
 
-extern void RenderPreferencesParam( renderdata *prd, char *szParam,
-				   char *szValue );
-extern char *RenderPreferencesCommand( renderdata *prd, char *sz );
+extern void RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue);
+extern void SaveRenderingSettings(FILE * pf);
 
 #if USE_BOARD3D
-char *WriteMaterial(Material* pMat);
-char* WriteMaterialDice(renderdata* prd, int num);
+char *WriteMaterial(Material * pMat);
+char *WriteMaterialDice(renderdata * prd, int num);
 #endif
 
 #endif
