@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: db_import.py,v 1.2 2007/07/02 12:50:13 ace Exp $
+# $Id: db_import.py,v 1.3 2013/06/16 03:03:07 mdpetch Exp $
 
 """
  db_import.py -- batch import of multiple sgf files into relational database
@@ -26,6 +26,7 @@
 
 import os
 
+
 def GetFiles(dir):
     "Look for gnubg import files in dir"
     try:
@@ -45,7 +46,7 @@ def GetFiles(dir):
             # Check has supported extension
             dot = file.rfind('.')
             if dot != -1:
-                ext = file[dot + 1 : ].lower()
+                ext = file[dot + 1:].lower()
                 if ext == "sgf":
                     foundBGFile = True
                     fileList.append(file)
@@ -59,18 +60,21 @@ def GetFiles(dir):
             print "  ** No sgf files found in directory **"
         return 0
 
+
 def ImportFile(prompt, file, dir):
     "Run commands to import stats into gnubg"
     print prompt + " Importing " + file
     gnubg.command('load match "' + dir + file + '"')
     gnubg.command('relational add match')
 
+
 def GetYN(prompt):
-    confirm = '';
+    confirm = ''
     while len(confirm) == 0 or (confirm[0] != 'y' and confirm[0] != 'n'):
         confirm = raw_input(prompt + " (y/n): ").lower()
     return confirm
 
+
 def GetDir(prompt):
     dir = raw_input(prompt)
     if dir:
@@ -79,6 +83,7 @@ def GetDir(prompt):
             dir = dir + '/'
     return dir
 
+
 def BatchImport():
     "Import stats for all sgf files in a directory"
 
@@ -101,7 +106,7 @@ def BatchImport():
     # Check user wants to continue
     if GetYN("Continue") == 'n':
         return
-    
+
     # Get stats for each file
     num = 0
     for file in inFiles:
